@@ -6,10 +6,6 @@ using FSpot.Xmp;
 using System.Collections;
 using System.Reflection;
 
-#if ENABLE_NUNIT
-using NUnit.Framework;
-#endif
-
 namespace FSpot.Png {
 	public class PngFile : ImageFile, SemWeb.StatementSource {
 		PngHeader header;
@@ -77,9 +73,10 @@ namespace FSpot.Png {
 					switch (text.Keyword) {
 					case "XMP":
 					case "XML:com.adobe.xmp":
-						System.IO.Stream xmpstream = new System.IO.MemoryStream (text.TextData);
-						FSpot.Xmp.XmpFile xmp = new FSpot.Xmp.XmpFile (xmpstream);
-						xmp.Select (sink);
+						using (System.IO.Stream xmpstream = new System.IO.MemoryStream (text.TextData)) {
+							FSpot.Xmp.XmpFile xmp = new FSpot.Xmp.XmpFile (xmpstream);
+							xmp.Select (sink);
+						}
 						break;
 					case "Comment":
 						MetadataStore.AddLiteral (sink, "exif:UserComment", text.Text);
@@ -88,16 +85,16 @@ namespace FSpot.Png {
 						MetadataStore.AddLiteral (sink, "xmp:CreatorTool", text.Text);
 						break;
 					case "Title":
-						MetadataStore.AddLiteral (sink, "dc:title", "rdf:Alt", new Literal (text.Text, "x-default", null));
+						MetadataStore.AddLiteral (sink, "dc:title", "rdf:Alt", new SemWeb.Literal (text.Text, "x-default", null));
 						break;
 					case "Author":
-						MetadataStore.AddLiteral (sink, "dc:creator", "rdf:Seq", new Literal (text.Text));
+						MetadataStore.AddLiteral (sink, "dc:creator", "rdf:Seq", new SemWeb.Literal (text.Text));
 						break;
 					case "Copyright":
-						MetadataStore.AddLiteral (sink, "dc:rights", "rdf:Alt", new Literal (text.Text, "x-default", null));
+						MetadataStore.AddLiteral (sink, "dc:rights", "rdf:Alt", new SemWeb.Literal (text.Text, "x-default", null));
 						break;
 					case "Description":
-						MetadataStore.AddLiteral (sink, "dc:description", "rdf:Alt", new Literal (text.Text, "x-default", null));
+						MetadataStore.AddLiteral (sink, "dc:description", "rdf:Alt", new SemWeb.Literal (text.Text, "x-default", null));
 						break;
 					case "Creation Time":
 						try {
@@ -344,37 +341,38 @@ namespace FSpot.Png {
 
 			public void SetText (byte [] raw)
 			{
-				MemoryStream stream = new MemoryStream ();
-				byte [] tmp;
+				using (MemoryStream stream = new MemoryStream ()) {
+					byte [] tmp;
+					
+					text_data = raw;
 
-				text_data = raw;
-
-				tmp = Latin1.GetBytes (keyword);
-				stream.Write (tmp, 0, tmp.Length);
-				stream.WriteByte (0);
-
-				stream.WriteByte ((byte)(compressed ? 1 : 0));
-				stream.WriteByte (Compression);
-
-				if (Language != null && Language != "") {
-					tmp = Latin1.GetBytes (Language);
+					tmp = Latin1.GetBytes (keyword);
 					stream.Write (tmp, 0, tmp.Length);
-				}
-				stream.WriteByte (0);
-
-				if (LocalizedKeyword != null && LocalizedKeyword != "") {
-					tmp = System.Text.Encoding.UTF8.GetBytes (LocalizedKeyword);
-					stream.Write (tmp, 0, tmp.Length);
-				}
-				stream.WriteByte (0);
+					stream.WriteByte (0);
+					
+					stream.WriteByte ((byte)(compressed ? 1 : 0));
+					stream.WriteByte (Compression);
+					
+					if (Language != null && Language != System.String.Empty) {
+						tmp = Latin1.GetBytes (Language);
+						stream.Write (tmp, 0, tmp.Length);
+					}
+					stream.WriteByte (0);
+					
+					if (LocalizedKeyword != null && LocalizedKeyword != System.String.Empty) {
+						tmp = System.Text.Encoding.UTF8.GetBytes (LocalizedKeyword);
+						stream.Write (tmp, 0, tmp.Length);
+					}
+					stream.WriteByte (0);
 				
-				if (compressed) {
-					tmp = Deflate (text_data, 0, text_data.Length);
-					stream.Write (tmp, 0, tmp.Length);
-				} else {
-					stream.Write (text_data, 0, text_data.Length);
+					if (compressed) {
+						tmp = Deflate (text_data, 0, text_data.Length);
+						stream.Write (tmp, 0, tmp.Length);
+					} else {
+						stream.Write (text_data, 0, text_data.Length);
+					}
+					this.data = stream.ToArray ();
 				}
-				this.data = stream.ToArray ();
 			}
 
 			public ItxtChunk (string name, byte [] data) : base (name, data) 
@@ -389,7 +387,7 @@ namespace FSpot.Png {
 				this.Name = "iTXt";
 				this.keyword = keyword;
 				this.Language = language;
-				this.LocalizedKeyword = "";
+				this.LocalizedKeyword = System.String.Empty;
 				this.compressed = compressed;
 				this.Compression = 0;
 			}
@@ -1208,14 +1206,14 @@ namespace FSpot.Png {
 					if (chunk is TextChunk) {
 						TextChunk text = (TextChunk) chunk;
 						System.Console.Write (" Text Chunk {0} {1}", 
-								      text.Keyword, "", "");
+								      text.Keyword, System.String.Empty, System.String.Empty);
 					}
 					
 					TimeChunk time = chunk as TimeChunk;
 					if (time != null)
 						System.Console.Write(" Time {0}", time.Time);
 
-					System.Console.WriteLine ("");
+					System.Console.WriteLine (System.String.Empty);
 #endif
 					
 					if (chunk.Name == "IEND")
@@ -1275,7 +1273,7 @@ namespace FSpot.Png {
 			using (System.IO.Stream output = System.IO.File.OpenWrite (temp_path)) {
 				Save (output);
 			}
-			if (FSpot.Unix.Rename (temp_path, path) < 0) {
+			if (FSpot.Utils.Unix.Rename (temp_path, path) < 0) {
 				System.IO.File.Delete (temp_path);
 				throw new System.Exception (System.String.Format ("Unable to rename {0} to {1}", temp_path, path));
 			}
@@ -1284,17 +1282,18 @@ namespace FSpot.Png {
 		public override void Save (Gdk.Pixbuf pixbuf, System.IO.Stream stream)
 		{
 			byte [] buffer = PixbufUtils.Save (pixbuf, "png", null, null);
-			MemoryStream mem = new MemoryStream (buffer);
-			PngHeader converted = new PngHeader (mem);
-
-			/* FIXME we need to update the XMP metadata here */
-			foreach (Chunk c in Chunks) {
-				if (c is TextChunk) {
-					converted.Insert (c);
+			using (MemoryStream mem = new MemoryStream (buffer)) {
+				PngHeader converted = new PngHeader (mem);
+				
+				/* FIXME we need to update the XMP metadata here */
+				foreach (Chunk c in Chunks) {
+					if (c is TextChunk) {
+						converted.Insert (c);
+					}
 				}
+				
+				converted.Save (stream);
 			}
-
-			converted.Save (stream);
 		}
 
 		public override Cms.Profile GetProfile ()
@@ -1404,9 +1403,10 @@ namespace FSpot.Png {
 				Chunks.Remove (text);
 
 			ItxtChunk itext = new ItxtChunk ("XML:com.adobe.xmp", "en", false);
-			MemoryStream stream = new MemoryStream ();
-			xmp.Save (stream);
-			itext.SetText (stream.ToArray ());
+			using (MemoryStream stream = new MemoryStream ()) {
+				xmp.Save (stream);
+				itext.SetText (stream.ToArray ());
+			}
 			Header.Insert (itext);
 		}
 
@@ -1418,127 +1418,11 @@ namespace FSpot.Png {
 				foreach (Chunk chunk in Chunks) {
 					TimeChunk time = chunk as TimeChunk;
 					if (time != null)
-						return time.Time.ToUniversalTime ();
+						return time.Time;
 				}
 				return base.Date;
 			}
 		}
 		
-#if ENABLE_NUNIT
-		[TestFixture]
-		public class Tests {
-			public Tests ()
-			{
-				Gnome.Vfs.Vfs.Initialize ();
-				Gtk.Application.Init ();
-			}
-
-			[Test]
-			public void Save ()
-			{
-				Gdk.Pixbuf test = new Gdk.Pixbuf (null, "f-spot-32.png");
-				string path = ImageFile.TempPath ("joe.png");
-				test.Save (path, "png");
-				PngFile pimg = new PngFile (path);
-
-				string desc = "this is a png test";
-				string desc2 = "\000xa9 Novell Inc.";
-				pimg.SetDescription (desc);
-				using (Stream stream = File.OpenWrite (path)) {
-					pimg.Save (stream);
-				}
-				PngFile mod = new PngFile (path);
-				Assert.AreEqual (mod.Orientation, PixbufOrientation.TopLeft);
-				Assert.AreEqual (mod.Description, desc);
-				pimg.SetDescription (desc2);
-
-				using (Stream stream = File.OpenWrite (path)) {
-					pimg.Save (stream);
-				}
-				mod = new PngFile (path);
-				Assert.AreEqual (mod.Description, desc2);
-				
-				File.Delete (path);
-			}
-
-			[Test]
-			public void Load ()
-			{
-				string desc = "(c) 2004 Jakub Steiner\n\nCreated with The GIMP";
-				Assembly assembly = System.Reflection.Assembly.GetExecutingAssembly ();
-				string path  = ImageFile.TempPath ("maddy.png");
-				using (Stream output = File.OpenWrite (path)) {
-					using (Stream source = assembly.GetManifestResourceStream ("f-spot-adjust-colors.png")) {
-						byte [] buffer = new byte [256];
-						while (source.Read (buffer, 0, buffer.Length) > 0) {
-							output.Write (buffer, 0, buffer.Length);
-						}
-					}
-				}
-				PngFile pimg = new PngFile (path);
-				Assert.AreEqual (pimg.Description, desc);
-
-				File.Delete (path);
-			}
-		}
-#endif
-
-#if false
-		public class ImageFile {
-			string Path;
-			public ImageFile (string path)
-			{
-				this.Path = path;
-			}
-		}
-
-		public static void Main (string [] args) 
-		{
-			System.Collections.ArrayList failed = new System.Collections.ArrayList ();
-			Gtk.Application.Init ();
-			foreach (string path in args) {
-				Gtk.Window win = new Gtk.Window (path);
-				Gtk.HBox box = new Gtk.HBox ();
-				box.Spacing = 12;
-				win.Add (box);
-				Gtk.Image image;
-				image = new Gtk.Image ();
-
-				System.DateTime start = System.DateTime.Now;
-				System.TimeSpan one = start - start;
-				System.TimeSpan two = start - start;
-				try {
-					start = System.DateTime.Now;
-					image.Pixbuf = new Gdk.Pixbuf (path);
-					one = System.DateTime.Now - start;
-				}  catch (System.Exception e) {
-				}
-				box.PackStart (image);
-
-				image = new Gtk.Image ();
-				try {
-					start = System.DateTime.Now;
-					PngFile png = new PngFile (path);
-					image.Pixbuf = png.GetPixbuf ();
-					two = System.DateTime.Now - start;
-				} catch (System.Exception e) {
-					failed.Add (path);
-					//System.Console.WriteLine ("Error loading {0}", path);
-					System.Console.WriteLine (e.ToString ());
-				}
-
-				System.Console.WriteLine ("{2} Load Time {0} vs {1}", one.TotalMilliseconds, two.TotalMilliseconds, path); 
-				box.PackStart (image);
-				win.ShowAll ();
-			}
-			
-			System.Console.WriteLine ("{0} Failed to Load", failed.Count);
-			foreach (string fail_path in failed) {
-				System.Console.WriteLine (fail_path);
-			}
-
-			Gtk.Application.Run ();
-		}
-#endif
 	}
 }
