@@ -1,3 +1,4 @@
+using FSpot;
 using Gdk;
 
 public abstract class ImportBackend {
@@ -6,11 +7,14 @@ public abstract class ImportBackend {
 	public abstract int Prepare ();
 
 	// Import one picture.  Returns false when done; then you have to call Finish().
-	public abstract bool Step (out Photo photo, out Pixbuf thumbnail, out int count);
+	public abstract bool Step (out StepStatusInfo import_info);
 
 	// Cancel importing.
 	public abstract void Cancel ();
 
 	// Complete importing (needs to be called).
 	public abstract void Finish ();
+
+	// The import roll. Should be set at Prepare () and removed at Cancel ()
+	protected Roll roll;
 }
