@@ -2,10 +2,13 @@ using Gtk;
 using Glade;
 using System;
 using Mono.Unix;
+using FSpot;
+using FSpot.Utils;
+using FSpot.UI.Dialog;
 
-public class PhotoVersionCommands {
-
-	private class VersionNameRequest : FSpot.GladeDialog {
+public class PhotoVersionCommands
+{
+	private class VersionNameRequest : GladeDialog {
 		private Photo photo;
 
 		[Glade.Widget] private Button ok_button;
@@ -26,7 +29,7 @@ public class PhotoVersionCommands {
 
 			if (photo.VersionNameExists (new_name)
 			    && ! (request_type == RequestType.Rename
-				  && new_name == photo.GetVersionName (photo.DefaultVersionId))) {
+				  && new_name == photo.GetVersion (photo.DefaultVersionId).Name)) {
 				already_in_use_label.Markup = "<small>This name is already in use</small>";
 				ok_button.Sensitive = false;
 				return;
@@ -59,7 +62,7 @@ public class PhotoVersionCommands {
 			case RequestType.Rename:
 				this.Dialog.Title = Catalog.GetString ("Rename Version");
 				prompt_label.Text = Catalog.GetString ("New name:");
-				version_name_entry.Text = photo.GetVersionName (photo.DefaultVersionId);
+				version_name_entry.Text = photo.GetVersion (photo.DefaultVersionId).Name;
 				version_name_entry.SelectRegion (0, -1);
 				break;
 			}
@@ -77,7 +80,7 @@ public class PhotoVersionCommands {
 			ResponseType response = (ResponseType) this.Dialog.Run ();
 
 			name = version_name_entry.Text;
-			if (request_type == RequestType.Rename && name == photo.GetVersionName (photo.DefaultVersionId))
+			if (request_type == RequestType.Rename && name == photo.GetVersion (photo.DefaultVersionId).Name)
 				response = ResponseType.Cancel;
 
 			this.Dialog.Destroy ();
@@ -137,7 +140,7 @@ public class PhotoVersionCommands {
 			dialog.AddButton (Catalog.GetString ("Delete"), (int) ResponseType.Ok);
 			dialog.DefaultResponse = ResponseType.Ok;
 
-			string version_name = photo.GetVersionName (photo.DefaultVersionId);
+			string version_name = photo.GetVersion (photo.DefaultVersionId).Name;
 			Label label = new Label (String.Format (Catalog.GetString ("Really delete version \"{0}\"?"), version_name));
 			label.Show ();
 			dialog.VBox.PackStart (label, false, true, 6);;
@@ -147,7 +150,7 @@ public class PhotoVersionCommands {
 					photo.DeleteVersion (photo.DefaultVersionId);
 					store.Commit (photo);
 				} catch (Exception e) {
-					// FIXME show error dialog.
+					Log.DebugException (e);
 					string msg = Catalog.GetString ("Could not delete a version");
 					string desc = String.Format (Catalog.GetString ("Received exception \"{0}\". Unable to delete version \"{1}\""),
 								     e.Message, photo.Name);
@@ -218,7 +221,7 @@ public class PhotoVersionCommands {
 						new_parent.DefaultVersionId = new_parent.CreateReparentedVersion (photo.GetVersion (version_id) as PhotoVersion);
 						store.Commit (new_parent);
 					} catch (Exception e) {
-						Console.WriteLine (e);	
+						Log.DebugException (e);	
 					}
 				}
 				uint [] version_ids = photo.VersionIds;
@@ -227,11 +230,10 @@ public class PhotoVersionCommands {
 					try {
 						photo.DeleteVersion (version_id, true, true);
 					} catch (Exception e) {
-						Console.WriteLine(e);
+						Log.DebugException (e);
 					}
 				}
-				store.Commit (photo);
-				MainWindow.Toplevel.Database.Photos.Remove (photos);
+				MainWindow.Toplevel.Database.Photos.Remove (photo);
 			}
 			return true;
 		}
