@@ -16,33 +16,9 @@ using Gdk;
 using Mono.Unix;
 
 using FSpot.Query;
+using FSpot.Utils;
 
 namespace FSpot.Widgets {
-	public class HighlightedBox : EventBox {
-        private bool changing_style = false;
-
-		public HighlightedBox(Widget child) : base()
-        {
-            Child = child;
-            AppPaintable = true;
-        }
-
-        protected override void OnStyleSet(Style style)
-        {
-            if (!changing_style) {
-                changing_style = true;
-                ModifyBg(StateType.Normal, Style.Background(StateType.Selected));
-                changing_style = false;
-            }
-        }
-
-        protected override bool OnExposeEvent(Gdk.EventExpose evnt)
-        {
-            GdkWindow.DrawRectangle(Style.ForegroundGC(StateType.Normal), false, 0, 0, Allocation.Width - 1, Allocation.Height - 1);
-            return base.OnExposeEvent(evnt);
-        }
-    }
-
 	public class FindBar : HighlightedBox {
 		private Entry entry;
 		private string last_entry_text = String.Empty;
@@ -74,7 +50,6 @@ namespace FSpot.Widgets {
 		public FindBar (PhotoQuery query, TreeModel model) : base(new HBox())
 		{
 			this.query = query;
-
             box = Child as HBox;
 
 			box.Spacing = 6;
@@ -109,7 +84,7 @@ namespace FSpot.Widgets {
 
 		private void HandleEntryTextInserted (object sender, TextInsertedArgs args)
 		{
-			//Console.WriteLine ("inserting {0}, ( = {1}  ) = {2}", args.Text, open_parens, close_parens);
+			//Log.Debug ("inserting {0}, ( = {1}  ) = {2}", args.Text, open_parens, close_parens);
 
 			//int start = args.Position - args.Length;
 
@@ -130,7 +105,7 @@ namespace FSpot.Widgets {
 				entry.TextInserted += HandleEntryTextInserted;
 				pos++;
 			}
-			//Console.WriteLine ("done w/ insert, {0}, ( = {1}  ) = {2}", args.Text, open_parens, close_parens);
+			//Log.Debugformat ("done w/ insert, {0}, ( = {1}  ) = {2}", args.Text, open_parens, close_parens);
 			last_entry_text = entry.Text;
 
 			QueueUpdate ();
@@ -139,8 +114,8 @@ namespace FSpot.Widgets {
 		private void HandleEntryTextDeleted (object sender, TextDeletedArgs args)
 		{
 			int length = args.EndPos - args.StartPos;
-			//Console.WriteLine ("start {0} end {1} len {2} last {3}", args.StartPos, args.EndPos, length, last_entry_text);
-			string txt = last_entry_text.Substring (args.StartPos, length);
+			//Log.Debug ("start {0} end {1} len {2} last {3}", args.StartPos, args.EndPos, length, last_entry_text);
+			string txt = length < 0 ? last_entry_text : last_entry_text.Substring (args.StartPos, length);
 
 			for (int i = 0; i < txt.Length; i++) {
 				if (txt [i] == '(')
@@ -199,7 +174,7 @@ namespace FSpot.Widgets {
 
 		// OPS The operators we support, case insensitive
 		//private static string op_str = "(?'Ops' or | and |, | \\s+ )";
-		private static string op_str = "(?'Ops' or | and |, )";
+		private static string op_str = "(?'Ops' "+ Catalog.GetString ("or") + " | "+ Catalog.GetString ("and")  + " |, )";
 
 		// Match literals, eg tags or other text to search on
 		private static string literal_str = "[^{0}{1}]+?";
@@ -227,9 +202,9 @@ namespace FSpot.Widgets {
 		private static void PrintGroup (GroupCollection groups, string name)
 		{
 			Group group = groups [name];
-			Console.WriteLine ("Name: {2} (success = {1}) group: {0}", group, group.Success, name);
+			Log.Debug ("Name: {2} (success = {1}) group: {0}", group, group.Success, name);
 			foreach (Capture capture in group.Captures) {
-				Console.WriteLine ("  Have capture: {0}", capture);
+				Log.Debug ("  Have capture: {0}", capture);
 			}
 		}
 
@@ -248,13 +223,13 @@ namespace FSpot.Widgets {
 
 			string indent = String.Format ("{0," + depth*2 + "}", " ");
 
-			//Console.WriteLine (indent + "Have text: {0}", txt);
+			//Log.Debug (indent + "Have text: {0}", txt);
 
 			// Match the query the user typed against our regular expression
 			Match match = term_regex.Match (txt);
 
 			if (!match.Success) {
-				//Console.WriteLine (indent + "Failed to match.");
+				//Log.Debug (indent + "Failed to match.");
 				return false;
 			}
 
@@ -274,12 +249,12 @@ namespace FSpot.Widgets {
 			}
 
 			if (!op_valid) {
-				Console.WriteLine (indent + "Ambiguous operator sequence.  Use parenthesis to explicitly define evaluation order.");
+				Log.Information (indent + "Ambiguous operator sequence.  Use parenthesis to explicitly define evaluation order.");
 				return false;
 			}
 
 			if (match.Groups ["Terms"].Captures.Count == 1 && match.Groups["NotTerm"].Captures.Count != 1) {
-				//Console.WriteLine (indent + "Unbreakable term: {0}", match.Groups ["Terms"].Captures [0]);
+				//Log.Debug (indent + "Unbreakable term: {0}", match.Groups ["Terms"].Captures [0]);
 				string literal;
 				bool is_negated = false;
 				Tag tag = null;
@@ -337,7 +312,7 @@ namespace FSpot.Widgets {
 						subterm = subterm.Remove (0, 1);
 					}
 
-					//Console.WriteLine (indent + "Breaking subterm apart: {0}", subterm);
+					//Log.Debug (indent + "Breaking subterm apart: {0}", subterm);
 
 					if (!ConstructQuery (us, depth + 1, subterm, negated))
 						return false;
@@ -355,7 +330,7 @@ namespace FSpot.Widgets {
 						subterm = subterm.Remove (0, 1);
 					}
 
-					//Console.WriteLine (indent + "Breaking not subterm apart: {0}", subterm);
+					//Log.Debug (indent + "Breaking not subterm apart: {0}", subterm);
 
 					if (!ConstructQuery (us, depth + 1, subterm, true))
 						return false;
@@ -417,7 +392,7 @@ namespace FSpot.Widgets {
 
 			if (ParensValid () && ConstructQuery (null, 0, entry.Text)) {
 				if (RootTerm != null) {
-					//Console.WriteLine("rootTerm = {0}", RootTerm);
+					//Log.Debug("rootTerm = {0}", RootTerm);
 					if (!(RootTerm is AndTerm)) {
 						// A little hacky, here to make sure the root term is a AndTerm which will
 						// ensure we handle the Hidden tag properly
@@ -426,7 +401,7 @@ namespace FSpot.Widgets {
 						root_term = root_parent;
 					}
 
-					//Console.WriteLine("rootTerm = {0}", RootTerm);
+					//Log.Debug("rootTerm = {0}", RootTerm);
 					if (!(RootTerm is AndTerm)) {
 						// A little hacky, here to make sure the root term is a AndTerm which will
 						// ensure we handle the Hidden tag properly
@@ -434,11 +409,11 @@ namespace FSpot.Widgets {
 						RootTerm.Parent = root_parent;
 						root_term = root_parent;
 					}
-					//Console.WriteLine ("condition = {0}", RootTerm.SqlCondition ());
-					query.ExtraCondition = RootTerm.SqlCondition ();
+					//Log.Debug ("condition = {0}", RootTerm.SqlCondition ());
+					query.TagTerm = new TagConditionWrapper (RootTerm.SqlCondition ());
 				} else {
-					query.ExtraCondition = null;
-					//Console.WriteLine ("root term is null");
+					query.TagTerm = null;
+					//Log.Debug ("root term is null");
 				}
 			}
 		}
@@ -534,7 +509,7 @@ namespace FSpot.Widgets {
 			entry.DeleteText (entry.Position - transformed_key.Length, entry.Position);
 
 			string name = args.Model.GetValue (args.Iter, TextColumn) as string;
-			//Console.WriteLine ("match selected..{0}", name);
+			//Log.Debug ("match selected..{0}", name);
 			int pos = entry.Position;
 
 			completing = true;
@@ -544,7 +519,7 @@ namespace FSpot.Widgets {
 			entry.Position += name.Length;
 
 			args.RetVal = true;
-			//Console.WriteLine ("done w/ match selected");
+			//Log.Debug.Format ("done w/ match selected");
 		}
 
 		string last_key = String.Empty;
@@ -568,7 +543,7 @@ namespace FSpot.Widgets {
 					int start = 0;
 					for (int i = entry.Position - 1; i >= 0; i--) {
 						if (key [i] == ' ' || key [i] == ')' || key [i] == '(') {
-							//Console.WriteLine ("have start break char at {0}", i);
+							//Log.Debug ("have start break char at {0}", i);
 							start = i + 1;
 							break;
 						}
@@ -582,7 +557,7 @@ namespace FSpot.Widgets {
 						}
 					}
 
-					//Console.WriteLine ("start = {0} end = {1}", start, end);
+					//Log.Debug ("start = {0} end = {1}", start, end);
 
 					int len = end - start + 1;
 					if (len > 0 && start < last_key.Length)
@@ -590,7 +565,7 @@ namespace FSpot.Widgets {
 					else
 						transformed_key = String.Empty;
 				}
-				//Console.WriteLine ("transformed key {0} into {1}", key, transformed_key);
+				//Log.Debug ("transformed key {0} into {1}", key, transformed_key);
 			}
 
 			if (transformed_key == String.Empty)
@@ -602,7 +577,7 @@ namespace FSpot.Widgets {
 			if (name == null || name.Length <= transformed_key.Length)
 				return false;
 
-			//Console.WriteLine ("entered = {0} compared to {1}", transformed_key, name);
+			//Log.Debug ("entered = {0} compared to {1}", transformed_key, name);
 			return (String.Compare (transformed_key, name.Substring(0, transformed_key.Length), true) == 0);
 		}
 	}
